==> CooldownCount_v0.06.zip: Interface/AddOns/CooldownCount/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_COOLDOWNCOUNTHEADER					= "Cooldown Count";
BINDING_NAME_COOLDOWNCOUNT							= "Cooldown Count Toggle";

COOLDOWNCOUNT_CONFIG_HEADER							= "Cooldown Count";
COOLDOWNCOUNT_CONFIG_HEADER_INFO					= "Contains settings for the Cooldown Count,\nan AddOn which displays the time until cooldown\nis done on actions.";

COOLDOWNCOUNT_ENABLED								= "Enable Cooldown Count";
COOLDOWNCOUNT_ENABLED_INFO							= "Enables Cooldown Count, displaying the time until cooldown is complete on actions.";

COOLDOWNCOUNT_SIDECOUNT								= "Offset SideBars Side Count";
COOLDOWNCOUNT_SIDECOUNT_INFO						= "Will make the cooldown counts on the sidebar be placed further to the middle of the screen.";

COOLDOWNCOUNT_FLASHSPEED							= "Time between wear-off flashes";
COOLDOWNCOUNT_FLASHSPEED_INFO						= "Determines how long time should be allowed between each flash when the cooldown timer is about to expire.";

COOLDOWNCOUNT_FLASHSPEED_SLIDER_DESCRIPTION			= "Length";
COOLDOWNCOUNT_FLASHSPEED_SLIDER_APPEND				= " second(s)";

COOLDOWNCOUNT_HOUR_FORMAT							= "%s h";
COOLDOWNCOUNT_MINUTES_FORMAT						= "%s m";

COOLDOWNCOUNT_HOUR_MINUTES_FORMAT					= "%s:%s\nhours";
COOLDOWNCOUNT_MINUTES_SECONDS_FORMAT				= "%s:%s\nmins";
COOLDOWNCOUNT_SECONDS_FORMAT						= "%s";

COOLDOWNCOUNT_SECONDS_LONG_FORMAT					= "%s s";

COOLDOWNCOUNT_CHAT_ENABLED							= "Cooldown Count enabled.";
COOLDOWNCOUNT_CHAT_DISABLED							= "Cooldown Count disabled.";

COOLDOWNCOUNT_CHAT_SIDECOUNT_ENABLED				= "Cooldown Count sidebar count offset enabled.";
COOLDOWNCOUNT_CHAT_SIDECOUNT_DISABLED				= "Cooldown Count sidebar count offset disabled.";

COOLDOWNCOUNT_CHAT_FLASHSPEED						= "Cooldown Count flash speed set to %s.";

COOLDOWNCOUNT_CHAT_COMMAND_ENABLE_INFO				= "Enables/disables Cooldown Count.";
COOLDOWNCOUNT_CHAT_COMMAND_SIDECOUNT_ENABLE_INFO	= "Enables/disables Cooldown Count side bar offset.";
COOLDOWNCOUNT_CHAT_COMMAND_FLASHSPEED_INFO			= "Sets how long the time should be (in seconds) between each flash when the cooldown is about to expire.";
COOLDOWNCOUNT_IMPERATIVE_ABILITY_MESSAGE			= "Use %s!";

==> CooldownCount_v0.08.zip: Interface/AddOns/CooldownCount/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_COOLDOWNCOUNTHEADER					= "Cooldown Count";
BINDING_NAME_COOLDOWNCOUNT							= "Cooldown Count Toggle";

COOLDOWNCOUNT_CONFIG_HEADER							= "Cooldown Count";
COOLDOWNCOUNT_CONFIG_HEADER_INFO					= "Contains settings for the Cooldown Count,\nan AddOn which displays the time until cooldown\nis done on actions.";

COOLDOWNCOUNT_ENABLED								= "Enable Cooldown Count";
COOLDOWNCOUNT_ENABLED_INFO							= "Enables Cooldown Count, displaying the time until cooldown is complete on actions.";

COOLDOWNCOUNT_SIDECOUNT								= "Offset SideBars Side Count";
COOLDOWNCOUNT_SIDECOUNT_INFO						= "Will make the cooldown counts on the sidebar be placed further to the middle of the screen.";

COOLDOWNCOUNT_FLASHSPEED							= "Time between wear-off flashes";
COOLDOWNCOUNT_FLASHSPEED_INFO						= "Determines how long time should be allowed between each flash when the cooldown timer is about to expire.";

COOLDOWNCOUNT_FLASHSPEED_SLIDER_DESCRIPTION			= "Length";
COOLDOWNCOUNT_FLASHSPEED_SLIDER_APPEND				= " second(s)";

COOLDOWNCOUNT_HOUR_FORMAT							= "%s h";
COOLDOWNCOUNT_MINUTES_FORMAT						= "%s m";

COOLDOWNCOUNT_HOUR_MINUTES_FORMAT					= "%s:%s";
COOLDOWNCOUNT_MINUTES_SECONDS_FORMAT				= "%s:%s";
COOLDOWNCOUNT_SECONDS_FORMAT						= "%s";

COOLDOWNCOUNT_SECONDS_LONG_FORMAT					= "%s s";

COOLDOWNCOUNT_CHAT_ENABLED							= "Cooldown Count enabled.";
COOLDOWNCOUNT_CHAT_DISABLED							= "Cooldown Count disabled.";

COOLDOWNCOUNT_CHAT_SIDECOUNT_ENABLED				= "Cooldown Count sidebar count offset enabled.";
COOLDOWNCOUNT_CHAT_SIDECOUNT_DISABLED				= "Cooldown Count sidebar count offset disabled.";

COOLDOWNCOUNT_CHAT_FLASHSPEED						= "Cooldown Count flash speed set to %s.";

COOLDOWNCOUNT_CHAT_COMMAND_ENABLE_INFO				= "Enables/disables Cooldown Count.";
COOLDOWNCOUNT_CHAT_COMMAND_SIDECOUNT_ENABLE_INFO	= "Enables/disables Cooldown Count side bar offset.";
COOLDOWNCOUNT_CHAT_COMMAND_FLASHSPEED_INFO			= "Sets how long the time should be (in seconds) between each flash when the cooldown is about to expire.";

COOLDOWNCOUNT_USERSCALE								= "Change the scale";
COOLDOWNCOUNT_USERSCALE_INFO						= "Manually changes the scale which CooldownCount uses. Strange results may occur. Default is 1.";
COOLDOWNCOUNT_USERSCALE_SLIDER_DESCRIPTION			= "Scale";
COOLDOWNCOUNT_USERSCALE_SLIDER_APPEND				= " percent";

COOLDOWNCOUNT_USERSCALE_							= "Cooldown Count user defined scale set to %s.";
